@@ -1,9 +1,10 @@
-"""Test cases for SuperFences."""
+"""Test cases for Tabbed (alternative style)."""
 from .. import util
+from pymdownx.slugs import slugify
 
 
-class TestLegacyTab(util.MdCase):
-    """Test legacy tab cases."""
+class TestTab(util.MdCase):
+    """Test tab cases."""
 
     extension = ['pymdownx.tabbed', 'pymdownx.superfences', 'markdown.extensions.def_list', 'pymdownx.details']
     extension_configs = {'pymdownx.tabbed': {'alternate_style': True}}
@@ -225,6 +226,70 @@ class TestLegacyTab(util.MdCase):
             True
         )
 
+    def test_tabbed_select(self):
+        """Test selecting a tab."""
+
+        self.check_markdown(
+            r'''
+            === "Tab 1"
+                content
+
+            ===+ "Tab 2"
+                content
+
+            === "Tab 3"
+                content
+            ''',
+            r'''
+            <div class="tabbed-set tabbed-alternate" data-tabs="1:3"><input id="__tabbed_1_1" name="__tabbed_1" type="radio" /><input checked="checked" id="__tabbed_1_2" name="__tabbed_1" type="radio" /><input id="__tabbed_1_3" name="__tabbed_1" type="radio" /><div class="tabbed-labels"><label for="__tabbed_1_1">Tab 1</label><label for="__tabbed_1_2">Tab 2</label><label for="__tabbed_1_3">Tab 3</label></div>
+            <div class="tabbed-content">
+            <div class="tabbed-block">
+            <p>content</p>
+            </div>
+            <div class="tabbed-block">
+            <p>content</p>
+            </div>
+            <div class="tabbed-block">
+            <p>content</p>
+            </div>
+            </div>
+            </div>
+            ''',  # noqa: E501
+            True
+        )
+
+    def test_tabbed_select_multiple(self):
+        """Test selecting multiple tabs."""
+
+        self.check_markdown(
+            r'''
+            === "Tab 1"
+                content
+
+            ===+ "Tab 2"
+                content
+
+            ===+ "Tab 3"
+                content
+            ''',
+            r'''
+            <div class="tabbed-set tabbed-alternate" data-tabs="1:3"><input id="__tabbed_1_1" name="__tabbed_1" type="radio" /><input id="__tabbed_1_2" name="__tabbed_1" type="radio" /><input checked="checked" id="__tabbed_1_3" name="__tabbed_1" type="radio" /><div class="tabbed-labels"><label for="__tabbed_1_1">Tab 1</label><label for="__tabbed_1_2">Tab 2</label><label for="__tabbed_1_3">Tab 3</label></div>
+            <div class="tabbed-content">
+            <div class="tabbed-block">
+            <p>content</p>
+            </div>
+            <div class="tabbed-block">
+            <p>content</p>
+            </div>
+            <div class="tabbed-block">
+            <p>content</p>
+            </div>
+            </div>
+            </div>
+            ''',  # noqa: E501
+            True
+        )
+
     def test_with_lists(self):
         """Test with lists."""
 
@@ -417,7 +482,11 @@ class TestLegacyTab(util.MdCase):
             <div class="tabbed-set tabbed-alternate" data-tabs="1:1"><input checked="checked" id="__tabbed_1_1" name="__tabbed_1" type="radio" /><div class="tabbed-labels"><label for="__tabbed_1_1">Output</label></div>
             <div class="tabbed-content">
             <div class="tabbed-block">
-            <details class="note" open="open"><summary>Open styled details</summary><details class="danger"><summary>Nested details!</summary><p>And more content again.</p>
+            <details class="note" open="open">
+            <summary>Open styled details</summary>
+            <details class="danger">
+            <summary>Nested details!</summary>
+            <p>And more content again.</p>
             </details>
             </details>
             </div>
@@ -492,3 +561,207 @@ class TestLegacyTab(util.MdCase):
             ''',  # noqa: E501
             True
         )
+
+    def test_indented_code(self):
+        """Test indented code."""
+
+        md = """
+        === "Tab 1"
+
+                code
+        """
+
+        self.check_markdown(
+            md,
+            '''
+            <div class="tabbed-set tabbed-alternate" data-tabs="1:1"><input checked="checked" id="__tabbed_1_1" name="__tabbed_1" type="radio" /><div class="tabbed-labels"><label for="__tabbed_1_1">Tab 1</label></div>
+            <div class="tabbed-content">
+            <div class="tabbed-block">
+            <pre><code>code
+            </code></pre>
+            </div>
+            </div>
+            </div>
+            ''',  # noqa: E501
+            True
+        )
+
+
+class TestLegacyTabSlugs(util.MdCase):
+    """Test legacy tab slug cases."""
+
+    extension = ['pymdownx.tabbed', 'toc']
+    extension_configs = {'pymdownx.tabbed': {'slugify': slugify(case='lower'), 'alternate_style': True}}
+
+    MD = """
+    ### Here is some text
+
+    === "Here is some text"
+        content
+
+    === "Here is some text"
+        content
+    """
+
+    def test_tab_slugs(self):
+        """Test tab slugs."""
+
+        self.check_markdown(
+            self.MD,
+            '''
+            <h3 id="here-is-some-text">Here is some text</h3>
+            <div class="tabbed-set tabbed-alternate" data-tabs="1:2"><input checked="checked" id="here-is-some-text_1" name="__tabbed_1" type="radio" /><input id="here-is-some-text_2" name="__tabbed_1" type="radio" /><div class="tabbed-labels"><label for="here-is-some-text_1">Here is some text</label><label for="here-is-some-text_2">Here is some text</label></div>
+            <div class="tabbed-content">
+            <div class="tabbed-block">
+            <p>content</p>
+            </div>
+            <div class="tabbed-block">
+            <p>content</p>
+            </div>
+            </div>
+            </div>
+            ''',  # noqa: E501
+            True
+        )
+
+
+class TestLegacyTabSlugsSep(util.MdCase):
+    """Test legacy tab slug separator cases."""
+
+    extension = ['pymdownx.tabbed', 'toc']
+    extension_configs = {
+        'pymdownx.tabbed': {'slugify': slugify(case='lower'), 'separator': '_', 'alternate_style': True}
+    }
+
+    MD = """
+    ### Here is some text
+
+    === "Here is some text"
+        content
+
+    === "Here is some text"
+        content
+    """
+
+    def test_slug_with_separator(self):
+        """Test tab slugs with separator."""
+
+        self.check_markdown(
+            self.MD,
+            '''
+            <h3 id="here-is-some-text">Here is some text</h3>
+            <div class="tabbed-set tabbed-alternate" data-tabs="1:2"><input checked="checked" id="here_is_some_text" name="__tabbed_1" type="radio" /><input id="here_is_some_text_1" name="__tabbed_1" type="radio" /><div class="tabbed-labels"><label for="here_is_some_text">Here is some text</label><label for="here_is_some_text_1">Here is some text</label></div>
+            <div class="tabbed-content">
+            <div class="tabbed-block">
+            <p>content</p>
+            </div>
+            <div class="tabbed-block">
+            <p>content</p>
+            </div>
+            </div>
+            </div>
+            ''',  # noqa: E501
+            True
+        )
+
+
+class TestTabSlugsCombineHeader(util.MdCase):
+    """Combine header slug with content tab."""
+
+    extension = ['pymdownx.tabbed', 'toc', 'pymdownx.details']
+    extension_configs = {
+        'pymdownx.tabbed': {
+            'slugify': slugify(case='lower'),
+            'combine_header_slug': True,
+            'alternate_style': True
+        }
+    }
+
+    def test_combine_header_slug(self):
+        """Test that slugs are a combination of the header slug and the tab title."""
+
+        md = R"""
+        ### Here is some text
+
+        === "First Tab"
+            content
+
+        ### Another header
+
+        ??? "title"
+            === "Second Tab"
+                content
+        """
+
+        self.check_markdown(
+            md,
+            '''
+            <h3 id="here-is-some-text">Here is some text</h3>
+            <div class="tabbed-set tabbed-alternate" data-tabs="1:1"><input checked="checked" id="here-is-some-text-first-tab" name="__tabbed_1" type="radio" /><div class="tabbed-labels"><label for="here-is-some-text-first-tab">First Tab</label></div>
+            <div class="tabbed-content">
+            <div class="tabbed-block">
+            <p>content</p>
+            </div>
+            </div>
+            </div>
+            <h3 id="another-header">Another header</h3>
+            <details>
+            <summary>title</summary>
+            <div class="tabbed-set tabbed-alternate" data-tabs="2:1"><input checked="checked" id="another-header-second-tab" name="__tabbed_2" type="radio" /><div class="tabbed-labels"><label for="another-header-second-tab">Second Tab</label></div>
+            <div class="tabbed-content">
+            <div class="tabbed-block">
+            <p>content</p>
+            </div>
+            </div>
+            </div>
+            </details>
+            ''',  # noqa: E501
+            True
+        )
+
+    def test_no_header(self):
+        """Test when there is no header."""
+
+        md = R"""
+        === "A Tab"
+            content
+        """
+
+        self.check_markdown(
+            md,
+            '''
+            <div class="tabbed-set tabbed-alternate" data-tabs="1:1"><input checked="checked" id="a-tab" name="__tabbed_1" type="radio" /><div class="tabbed-labels"><label for="a-tab">A Tab</label></div>
+            <div class="tabbed-content">
+            <div class="tabbed-block">
+            <p>content</p>
+            </div>
+            </div>
+            </div>
+            ''',  # noqa: E501
+            True
+        )
+
+    def test_header_after(self):
+        """Test when header comes after."""
+
+        md = R"""
+        === "A Tab"
+            content
+
+        # Header
+        """
+
+        self.check_markdown(
+            md,
+            '''
+            <div class="tabbed-set tabbed-alternate" data-tabs="1:1"><input checked="checked" id="a-tab" name="__tabbed_1" type="radio" /><div class="tabbed-labels"><label for="a-tab">A Tab</label></div>
+            <div class="tabbed-content">
+            <div class="tabbed-block">
+            <p>content</p>
+            </div>
+            </div>
+            </div>
+            <h1 id="header">Header</h1>
+            ''',  # noqa: E501
+            True
+        )
